obelisk.types.ObeliskKind
=========================

.. currentmodule:: obelisk.types

.. autoclass:: ObeliskKind
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~ObeliskKind.CLASSIC
      ~ObeliskKind.HFS
   
   